==> vertigo-quarto-impl-0.6.2-tests.jar: io/vertigo/quarto/publisher/mock/DtResources.java <==
/**
 * vertigo - simple java starter
 *
 * Copyright (C) 2013, KleeGroup, direction.technique@kleegroup.com (http://www.kleegroup.com)
 * KleeGroup, Centre d'affaire la Boursidiere - BP 159 - 92357 Le Plessis Robinson Cedex - France
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.vertigo.quarto.publisher.mock;

import io.vertigo.core.lang.MessageKey;

/**
 * Attention cette classe est générée automatiquement !
 * Resources du module io.vertigo.publisher.mock
 */
public enum DtResources implements MessageKey {

	/***********************************************************
	/** ADDRESS.
	/***********************************************************
	/**
	 * Rue.
	 */
	FLD_ADDRESS$RUE,
	/**
	 * Ville.
	 */
	FLD_ADDRESS$VILLE,

	/***********************************************************
	/** ENQUETE.
	/***********************************************************
	/**
	 * Terminée?.
	 */
	FLD_ENQUETE$ENQUETE_TERMINEE,
	/**
	 * Code.
	 */
	FLD_ENQUETE$CODE_ENQUETE,
	/**
	 * Sexe.
	 */
	FLD_ENQUETE$FAIT,
	/**
	 * Sexe.
	 */
	FLD_ENQUETE$SI_GRAVE,

	/***********************************************************
	/** ENQUETEUR.
	/***********************************************************
	/**
	 * Nom.
	 */
	FLD_ENQUETEUR$NOM,
	/**
	 * Prenom.
	 */
	FLD_ENQUETEUR$PRENOM,

	/***********************************************************
	/** MIS_EN_CAUSE.
	/***********************************************************
	/**
	 * Sexe.
	 */
	FLD_MIS_EN_CAUSE$SI_HOMME,
	/**
	 * Nom.
	 */
	FLD_MIS_EN_CAUSE$NOM,
	/**
	 * Prenom.
	 */
	FLD_MIS_EN_CAUSE$PRENOM,
	/**
	 * Addresses connues.
	 */
	FLD_MIS_EN_CAUSE$ADRESSES_CONNUES,

	/***********************************************************
	/** PUBLISHER_MOCK.
	/***********************************************************
	/**
	 * Titre.
	 */
	FLD_PUBLISHER_MOCK$TITRE,
	/**
	 * Nom.
	 */
	FLD_PUBLISHER_MOCK$NOM,
	/**
	 * Prénom.
	 */
	FLD_PUBLISHER_MOCK$PRENOM,
	/**
	 * Adresse (multi ligne).
	 */
	FLD_PUBLISHER_MOCK$ADDRESS,
	/**
	 * Commentaire (multi paragraphe).
	 */
	FLD_PUBLISHER_MOCK$COMMENTAIRE,
	/**
	 * booleen 1.
	 */
	FLD_PUBLISHER_MOCK$BOOLEAN_1,
	/**
	 * booleen 2.
	 */
	FLD_PUBLISHER_MOCK$BOOLEAN_2,
	/**
	 * booleen 3.
	 */
	FLD_PUBLISHER_MOCK$BOOLEAN_3,
	/**
	 * Test champs inutilisé.
	 */
	FLD_PUBLISHER_MOCK$TEST_DUMMY,
	/**
	 * Test long.
	 */
	FLD_PUBLISHER_MOCK$TEST_LONG,
	/**
	 * Test double.
	 */
	FLD_PUBLISHER_MOCK$TEST_DOUBLE,
	/**
	 * Test integer.
	 */
	FLD_PUBLISHER_MOCK$TEST_INTEGER,
	/**
	 * Test date.
	 */
	FLD_PUBLISHER_MOCK$TEST_DATE,
	/**
	 * Test list.
	 */
	FLD_PUBLISHER_MOCK$DTC_TEST,

	/***********************************************************
	/** VILLE.
	/***********************************************************
	/**
	 * Nom.
	 */
	FLD_VILLE$NOM,
	/**
	 * Code postal.
	 */
	FLD_VILLE$CODE_POSTAL,
}

==> vertigo-quarto-impl-0.7.1-tests.jar: io/vertigo/quarto/publisher/mock/DtResources.java <==
/**
 * vertigo - simple java starter
 *
 * Copyright (C) 2013, KleeGroup, direction.technique@kleegroup.com (http://www.kleegroup.com)
 * KleeGroup, Centre d'affaire la Boursidiere - BP 159 - 92357 Le Plessis Robinson Cedex - France
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.vertigo.quarto.publisher.mock;

import io.vertigo.lang.MessageKey;

/**
 * Attention cette classe est générée automatiquement !
 * Resources du module io.vertigo.publisher.mock
 */
public enum DtResources implements MessageKey {

	/***********************************************************
	/** ADDRESS.
	/***********************************************************
	/**
	 * Rue.
	 */
	FLD_ADDRESS$RUE,
	/**
	 * Ville.
	 */
	FLD_ADDRESS$VILLE,

	/***********************************************************
	/** ENQUETE.
	/***********************************************************
	/**
	 * Terminée?.
	 */
	FLD_ENQUETE$ENQUETE_TERMINEE,
	/**
	 * Code.
	 */
	FLD_ENQUETE$CODE_ENQUETE,
	/**
	 * Sexe.
	 */
	FLD_ENQUETE$FAIT,
	/**
	 * Sexe.
	 */
	FLD_ENQUETE$SI_GRAVE,

	/***********************************************************
	/** ENQUETEUR.
	/***********************************************************
	/**
	 * Nom.
	 */
	FLD_ENQUETEUR$NOM,
	/**
	 * Prenom.
	 */
	FLD_ENQUETEUR$PRENOM,

	/***********************************************************
	/** MIS_EN_CAUSE.
	/***********************************************************
	/**
	 * Sexe.
	 */
	FLD_MIS_EN_CAUSE$SI_HOMME,
	/**
	 * Nom.
	 */
	FLD_MIS_EN_CAUSE$NOM,
	/**
	 * Prenom.
	 */
	FLD_MIS_EN_CAUSE$PRENOM,
	/**
	 * Addresses connues.
	 */
	FLD_MIS_EN_CAUSE$ADRESSES_CONNUES,

	/***********************************************************
	/** PUBLISHER_MOCK.
	/***********************************************************
	/**
	 * Titre.
	 */
	FLD_PUBLISHER_MOCK$TITRE,
	/**
	 * Nom.
	 */
	FLD_PUBLISHER_MOCK$NOM,
	/**
	 * Prénom.
	 */
	FLD_PUBLISHER_MOCK$PRENOM,
	/**
	 * Adresse (multi ligne).
	 */
	FLD_PUBLISHER_MOCK$ADDRESS,
	/**
	 * Commentaire (multi paragraphe).
	 */
	FLD_PUBLISHER_MOCK$COMMENTAIRE,
	/**
	 * booleen 1.
	 */
	FLD_PUBLISHER_MOCK$BOOLEAN_1,
	/**
	 * booleen 2.
	 */
	FLD_PUBLISHER_MOCK$BOOLEAN_2,
	/**
	 * booleen 3.
	 */
	FLD_PUBLISHER_MOCK$BOOLEAN_3,
	/**
	 * Test champs inutilisé.
	 */
	FLD_PUBLISHER_MOCK$TEST_DUMMY,
	/**
	 * Test long.
	 */
	FLD_PUBLISHER_MOCK$TEST_LONG,
	/**
	 * Test double.
	 */
	FLD_PUBLISHER_MOCK$TEST_DOUBLE,
	/**
	 * Test integer.
	 */
	FLD_PUBLISHER_MOCK$TEST_INTEGER,
	/**
	 * Test date.
	 */
	FLD_PUBLISHER_MOCK$TEST_DATE,
	/**
	 * Test list.
	 */
	FLD_PUBLISHER_MOCK$DTC_TEST,

	/***********************************************************
	/** VILLE.
	/***********************************************************
	/**
	 * Nom.
	 */
	FLD_VILLE$NOM,
	/**
	 * Code postal.
	 */
	FLD_VILLE$CODE_POSTAL,
}
